(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     11090,        359]
NotebookOptionsPosition[     10001,        321]
NotebookOutlinePosition[     10361,        337]
CellTagsIndexPosition[     10318,        334]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"e", ">", "0"}], "&&", 
    RowBox[{"r", ">", "0"}], " ", "&&", " ", 
    RowBox[{"\[Mu]", ">", " ", "0"}], " ", "&&", " ", 
    RowBox[{"\[Nu]", " ", "\[GreaterEqual]", " ", "0"}], " ", "&&", " ", 
    RowBox[{"\[Nu]", " ", "\[LessEqual]", " ", "0.5"}], " ", "&&", " ", 
    RowBox[{"t", " ", ">", " ", "0"}], " ", "&&", " ", 
    RowBox[{"r", "\[Element]", "Reals"}], "&&", 
    RowBox[{"e", "\[Element]", "Reals"}], " ", "&&", " ", 
    RowBox[{"\[Mu]", "\[Element]", "Reals"}], " ", "&&", 
    RowBox[{"\[Nu]", " ", "\[Element]", "Reals"}], " ", "&&", " ", 
    RowBox[{"t", "\[Element]", "Reals"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.7252082463178997`*^9, {3.725208641336828*^9, 3.7252086673919888`*^9}, {
   3.72520902449586*^9, 3.7252090352075567`*^9}, {3.725209926422124*^9, 
   3.725209929866805*^9}, 3.7252100982620773`*^9, {3.725210274874835*^9, 
   3.725210309503572*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"re", "[", "r_", "]"}], ":=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"r", "^", "2"}], " ", "+", " ", 
     RowBox[{"e", "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725208253504199*^9, 3.7252082838671923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Beta]", ":=", 
   RowBox[{"Sqrt", "[", "\[Mu]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725210233195986*^9, 3.725210268168703*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", ":=", " ", 
   RowBox[{"\[Beta]", " ", "*", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", "*", "\[Nu]"}]}], ")"}]}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.7252090716999598`*^9, 3.725209081755821*^9}, {
  3.725209154521501*^9, 3.725209192297665*^9}, {3.725209935586605*^9, 
  3.7252099749793863`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Pseudo", "-", "Potentials"}], "*)"}]], "Input",
 CellChangeTimes->{{3.7252099954163857`*^9, 3.7252100103043213`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Q", "[", 
    RowBox[{"r_", ",", "s_", ",", "w_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"2", "*", 
     RowBox[{
      RowBox[{"r", "^", "3"}], "/", 
      RowBox[{"re", "[", "r", "]"}]}]}], " ", "-", " ", 
    RowBox[{"s", "*", " ", "w", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", "/", 
        RowBox[{"re", "[", "s", "]"}]}], " ", "+", " ", 
       RowBox[{"w", "/", 
        RowBox[{"re", "[", "w", "]"}]}]}], ")"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"e", "^", "2"}], "*", 
     RowBox[{"(", 
      RowBox[{"s", "-", "r"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"re", "[", "s", "]"}]}], " ", "-", " ", 
       RowBox[{"1", "/", 
        RowBox[{"re", "[", "w", "]"}]}]}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725208286069982*^9, 3.7252083485613747`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"r_", ",", "t_", ",", "c_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Q", "[", 
     RowBox[{"r", ",", 
      RowBox[{"r", "+", 
       RowBox[{"c", "*", "t"}]}], ",", 
      RowBox[{"r", "-", 
       RowBox[{"c", "*", "t"}]}]}], "]"}], " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"16", "*", "Pi", "*", 
      RowBox[{"c", "^", "2"}], "*", 
      RowBox[{"r", "^", "3"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725208356987977*^9, 3.725208391423867*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dQ", "[", 
    RowBox[{"r_", ",", "s_", ",", "w_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "*", 
     RowBox[{"r", "^", "2"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "/", 
        RowBox[{"re", "[", "r", "]"}]}], "-", 
       RowBox[{
        RowBox[{"r", "^", "2"}], "/", 
        RowBox[{
         RowBox[{"re", "[", "r", "]"}], "^", "3"}]}]}], ")"}]}], " ", "-", 
    " ", 
    RowBox[{"2", "*", "r", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", "/", 
        RowBox[{"re", "[", "s", "]"}]}], "+", 
       RowBox[{"w", "/", 
        RowBox[{"re", "[", "w", "]"}]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"e", "^", "2"}], "*", "r", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", "/", 
        RowBox[{
         RowBox[{"re", "[", "s", "]"}], "^", "3"}]}], " ", "+", " ", 
       RowBox[{"w", "/", 
        RowBox[{
         RowBox[{"re", "[", "w", "]"}], "^", "3"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.725208408964971*^9, 3.7252084736537027`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dU", "[", 
    RowBox[{"r_", ",", "t_", ",", "c_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dQ", "[", 
       RowBox[{"r", ",", 
        RowBox[{"r", "+", 
         RowBox[{"c", "*", "t"}]}], ",", 
        RowBox[{"r", "-", 
         RowBox[{"c", "*", "t"}]}]}], "]"}], " ", "-", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "/", "r"}], ")"}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"r", ",", 
         RowBox[{"r", "+", 
          RowBox[{"c", "*", "t"}]}], ",", 
         RowBox[{"r", "-", 
          RowBox[{"c", "*", "t"}]}]}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"16", "*", "Pi", "*", 
      RowBox[{"c", "^", "2"}], "*", 
      RowBox[{"r", "^", "3"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725208478073812*^9, 3.725208530458951*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Push", " ", "Dynamic", " ", "Kelvinlet"}], "*)"}]], "Input",
 CellChangeTimes->{{3.725210014904009*^9, 3.725210020303966*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"r", ",", "t", ",", "\[Alpha]"}], "]"}], " ", "+", " ", 
    RowBox[{"2", "*", 
     RowBox[{"U", "[", 
      RowBox[{"r", ",", "t", ",", "\[Beta]"}], "]"}]}], "+", 
    RowBox[{"r", "*", 
     RowBox[{"dU", "[", 
      RowBox[{"r", ",", "t", ",", "\[Beta]"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7252085429046288`*^9, 3.725208548052951*^9}, {
  3.725208591403551*^9, 3.725208614953425*^9}, {3.725208998224698*^9, 
  3.725209018016144*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dU", "[", 
       RowBox[{"r", ",", "t", ",", "\[Alpha]"}], "]"}], " ", "-", " ", 
      RowBox[{"dU", "[", 
       RowBox[{"r", ",", "t", ",", "\[Beta]"}], "]"}]}], ")"}], "/", "r"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.725208679733494*^9, 3.7252086956710777`*^9}, {
  3.725209004768283*^9, 3.725209020399847*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Regularized", " ", "Kelvinlet"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"a", ":=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "Pi", "*", "\[Mu]"}], ")"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.725209742533205*^9, 3.7252097647835693`*^9}, {
  3.7252103505172157`*^9, 3.725210352362034*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", ":=", 
   RowBox[{"a", "/", 
    RowBox[{"(", 
     RowBox[{"4", "*", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Nu]"}], ")"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725209769253924*^9, 3.72520981478209*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AA", "[", "r_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "/", 
     RowBox[{"re", "[", "r", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "/", "2"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"e", "^", "2"}], "/", 
       RowBox[{
        RowBox[{"re", "[", "r", "]"}], "^", "3"}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.725209828598633*^9, 3.725209863396645*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BB", "[", "r_", "]"}], ":=", " ", 
   RowBox[{"b", "/", 
    RowBox[{
     RowBox[{"re", "[", "r", "]"}], "^", "3"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.725209864589231*^9, 3.725209877140123*^9}}],

Cell[BoxData[
 RowBox[{"(*", "Verification", "*)"}]], "Input",
 CellChangeTimes->{{3.725209893839048*^9, 3.7252098981711693`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"r", ",", "t"}], "]"}], ",", 
     RowBox[{"t", "\[Rule]", " ", "Infinity"}]}], "]"}], " ", "-", " ", 
   RowBox[{"AA", "[", "r", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7252099088368196`*^9, 3.72520991037106*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7252099155774927`*^9, 3.725210065250103*^9, {3.7252103404009733`*^9, 
   3.725210366544869*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"B", "[", 
      RowBox[{"r", ",", "t"}], "]"}], ",", " ", 
     RowBox[{"t", "\[Rule]", " ", "Infinity"}]}], "]"}], " ", "-", " ", 
   RowBox[{"BB", "[", "r", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.725210035751316*^9, 3.725210071922007*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7252100860640697`*^9, {3.725210353132976*^9, 3.725210366608313*^9}}]
}, Open  ]]
},
WindowSize->{712, 756},
WindowMargins->{{Automatic, 131}, {Automatic, 26}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 974, 19, 54, "Input"],
Cell[1535, 41, 291, 8, 32, "Input"],
Cell[1829, 51, 176, 4, 32, "Input"],
Cell[2008, 57, 477, 13, 32, "Input"],
Cell[2488, 72, 158, 3, 32, "Input"],
Cell[2649, 77, 905, 27, 54, "Input"],
Cell[3557, 106, 538, 16, 32, "Input"],
Cell[4098, 124, 1089, 35, 54, "Input"],
Cell[5190, 161, 881, 27, 54, "Input"],
Cell[6074, 190, 167, 3, 32, "Input"],
Cell[6244, 195, 606, 16, 32, "Input"],
Cell[6853, 213, 489, 14, 32, "Input"],
Cell[7345, 229, 389, 10, 54, "Input"],
Cell[7737, 241, 267, 8, 32, "Input"],
Cell[8007, 251, 539, 18, 32, "Input"],
Cell[8549, 271, 251, 7, 32, "Input"],
Cell[8803, 280, 130, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[8958, 286, 355, 9, 32, "Input"],
Cell[9316, 297, 149, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9502, 305, 359, 9, 32, "Input"],
Cell[9864, 316, 121, 2, 66, "Output"]
}, Open  ]]
}
]
*)

